@@ -924,8 +924,12 @@ enum tcc_token {
 #else
 /* XXX: need to define this to use them in non ISOC99 context */
 extern float strtof (const char *__nptr, char **__endptr);
+#ifdef __ANDROID__
+#  define strtold (long double)strtod
+#else
 extern long double strtold (const char *__nptr, char **__endptr);
 #endif
+#endif
 
 #ifdef _WIN32
 #define IS_DIRSEP(c) (c == '/' || c == '\\')
